==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/language/1/barnraiser_01/mag_common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//MENU
$lang['menu_latest'] = 							"latest";
$lang['menu_blog'] = 							"blogs";
$lang['menu_library'] = 						"wiki pages";
$lang['menu_forum_subject'] = 					"forum subjects";
$lang['menu_polls'] = 							"polls";


//SECTION
$lang['section_menu'] = 						"menu";
$lang['section_action'] = 						"do";
$lang['section_blogs'] = 						"blogs";
$lang['section_subjects'] = 					"subjects";
$lang['section_polls'] = 						"polls";
$lang['section_library_items'] = 				"wiki pages";


//TXT
$lang['txt_magazine_name'] =					"splash"; //for breadcrumb
$lang['txt_check_spelling'] =					"Check Spelling";
$lang['txt_author'] =							"author";

?>

==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/language/1/barnraiser_01/mag_common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//MENU
$lang['menu_latest'] = 							"latest";
$lang['menu_blog'] = 							"blogs";
$lang['menu_library'] = 						"wiki pages";
$lang['menu_forum_subject'] = 					"forum subjects";
$lang['menu_polls'] = 							"polls";


//SECTION
$lang['section_menu'] = 						"menu";
$lang['section_action'] = 						"do";
$lang['section_blogs'] = 						"blogs";
$lang['section_subjects'] = 					"subjects";
$lang['section_polls'] = 						"polls";
$lang['section_library_items'] = 				"wiki pages";


//TXT
$lang['txt_magazine_name'] =					"splash"; //for breadcrumb
$lang['txt_check_spelling'] =					"Check Spelling";
$lang['txt_author'] =							"author";
$lang['txt_non_member'] = 						"NON MEMBER";
$lang['txt_joined'] = 							"Joined";
$lang['txt_hometown'] = 						"Hometown";

?>
